@@ -1,5 +1,5 @@
 
-#include <cmpinclude.h>
+#include "cmpinclude.h"
 #include "cmpspecial.h"
 init_cmpspecial(){do_init(VV);}
 /*	local entry for function C1QUOTE	*/
@@ -155,7 +155,7 @@ T66:;
 T78:;
 	base[2]= cadr((V32));
 	vs_top=(vs_base=base+2)+1;
-	(void) (*Lnk49)();
+	Leval();
 	vs_top=sup;
 	V33= vs_base[0];
 T76:;
@@ -262,23 +262,19 @@ T107:;
 	VMR7(V46)}
 T115:;
 	{object V47;
-	base[0]= get((V45),VV[15],Cnil);
-	vs_top=(vs_base=base+0)+1;
-	(void) (*Lnk62)();
-	vs_top=sup;
-	V48= vs_base[0];
-	V47= (VFUN_NARGS=2,(*(LnkLI61))(VV[14],V48));
+	V48= get((V45),VV[15],Cnil);
+	V47= (VFUN_NARGS=2,(*(LnkLI61))(VV[14],((V48)==Cnil?Ct:Cnil)));
 	{object V49 = list(3,VV[11],(V47),list(3,VV[16],(V47),(V45)));
 	VMR7(V49)}}
 T112:;
 	if(!(type_of((V45))==t_cons)){
-	goto T124;}
+	goto T123;}
 	if(!((car((V45)))==(VV[17]))){
-	goto T124;}
+	goto T123;}
 	if(!(endp(cdr((V45))))){
-	goto T128;}
+	goto T127;}
 	(void)((VFUN_NARGS=2,(*(LnkLI53))(VV[18],(V45))));
-T128:;
+T127:;
 	base[0]= make_cons(VV[20],symbol_value(VV[19]));
 	base[1]= make_cons(VV[20],symbol_value(VV[21]));
 	base[2]= make_cons(VV[20],symbol_value(VV[22]));
@@ -287,14 +283,14 @@ T128:;
 	bds_bind(VV[21],base[1]);
 	bds_bind(VV[22],base[2]);
 	bds_bind(VV[23],base[3]);
-	V45= (VFUN_NARGS=1,(*(LnkLI63))(cdr((V45))));
+	V45= (VFUN_NARGS=1,(*(LnkLI62))(cdr((V45))));
 	{object V50 = list(3,VV[11],cadr((V45)),(V45));
 	bds_unwind1;
 	bds_unwind1;
 	bds_unwind1;
 	bds_unwind1;
 	VMR7(V50)}
-T124:;
+T123:;
 	{object V51 = (VFUN_NARGS=2,(*(LnkLI53))(VV[24],(V45)));
 	VMR7(V51)}}}
 }
@@ -306,48 +302,48 @@ register object V53;
 {	 VMB8 VMS8 VMV8
 TTL:;
 	{object V54= car((V53));
-	if((V54!= VV[16]))goto T137;
-	V55= list(2,VV[25],(*(LnkLI65))(caddr((V53))));
-	{object V56 = (VFUN_NARGS=1,(*(LnkLI64))(/* INLINE-ARGS */V55));
+	if((V54!= VV[16]))goto T136;
+	V55= list(2,VV[25],(*(LnkLI64))(caddr((V53))));
+	{object V56 = (VFUN_NARGS=1,(*(LnkLI63))(/* INLINE-ARGS */V55));
 	VMR8(V56)}
-T137:;
-	if((V54!= VV[12]))goto T138;
+T136:;
+	if((V54!= VV[12]))goto T137;
 	if((cadddr((V53)))==Cnil){
-	goto T140;}
+	goto T139;}
 	V57= list(2,VV[26],structure_ref(caddr((V53)),VV[27],2));
-	{object V58 = (VFUN_NARGS=1,(*(LnkLI64))(/* INLINE-ARGS */V57));
+	{object V58 = (VFUN_NARGS=1,(*(LnkLI63))(/* INLINE-ARGS */V57));
 	VMR8(V58)}
-T140:;
+T139:;
 	V59= list(2,VV[28],structure_ref(caddr((V53)),VV[27],1));
-	{object V60 = (VFUN_NARGS=1,(*(LnkLI64))(/* INLINE-ARGS */V59));
+	{object V60 = (VFUN_NARGS=1,(*(LnkLI63))(/* INLINE-ARGS */V59));
 	VMR8(V60)}
-T138:;
+T137:;
 	{register object V61;
 	setq(VV[32],number_plus(symbol_value(VV[32]),small_fixnum(1)));
-	V61= (VFUN_NARGS=4,(*(LnkLI66))(VV[29],VV[30],VV[31],symbol_value(VV[32])));
+	V61= (VFUN_NARGS=4,(*(LnkLI65))(VV[29],VV[30],VV[31],symbol_value(VV[32])));
 	if((symbol_value(VV[34]))!=Cnil){
-	goto T148;}
+	goto T147;}
 	V62= Cnil;
-	goto T146;
-T148:;
+	goto T145;
+T147:;
 	V62= make_cons(small_fixnum(0),small_fixnum(0));
-T146:;
+T145:;
 	V63= list(5,VV[30],V62,symbol_value(VV[35]),(V61),(V53));
 	setq(VV[33],make_cons(/* INLINE-ARGS */V63,symbol_value(VV[33])));
 	setq(VV[36],make_cons((V61),symbol_value(VV[36])));
 	if((symbol_value(VV[34]))==Cnil){
-	goto T153;}
+	goto T152;}
 	V64= list(3,VV[37],structure_ref((V61),VV[27],3),symbol_value(VV[34]));
-	{object V65 = (VFUN_NARGS=1,(*(LnkLI64))(/* INLINE-ARGS */V64));
+	{object V65 = (VFUN_NARGS=1,(*(LnkLI63))(/* INLINE-ARGS */V64));
 	VMR8(V65)}
-T153:;
-	(void)((*(LnkLI67))(Cnil));{object V66;
+T152:;
+	(void)((*(LnkLI66))(Cnil));{object V66;
 	V66= symbol_value(VV[39]);
 	V67= structure_ref((V61),VV[27],3);
-	V68= list(3,VV[38],V66,list(3,VV[40],Cnil,(*(LnkLI69))(VV[41],/* INLINE-ARGS */V67)));
-	(void)((VFUN_NARGS=2,(*(LnkLI68))(/* INLINE-ARGS */V68,Ct)));}
+	V68= list(3,VV[38],V66,list(3,VV[40],Cnil,(*(LnkLI68))(VV[41],/* INLINE-ARGS */V67)));
+	(void)((VFUN_NARGS=2,(*(LnkLI67))(/* INLINE-ARGS */V68,Ct)));}
 	V69= list(2,VV[42],symbol_value(VV[39]));
-	{object V70 = (VFUN_NARGS=1,(*(LnkLI64))(/* INLINE-ARGS */V69));
+	{object V70 = (VFUN_NARGS=1,(*(LnkLI63))(/* INLINE-ARGS */V69));
 	VMR8(V70)}}}
 }
 /*	local entry for function WT-SYMBOL-FUNCTION	*/
@@ -358,15 +354,15 @@ object V72;
 {	 VMB9 VMS9 VMV9
 TTL:;
 	if((symbol_value(VV[43]))==Cnil){
-	goto T158;}
+	goto T157;}
 	princ_str("symbol_function(VV[",VV[44]);
-	(void)((*(LnkLI70))((V72)));
+	(void)((*(LnkLI69))((V72)));
 	princ_str("])",VV[44]);
 	{object V73 = Cnil;
 	VMR9(V73)}
-T158:;
+T157:;
 	princ_str("(VV[",VV[44]);
-	(void)((*(LnkLI70))((V72)));
+	(void)((*(LnkLI69))((V72)));
 	princ_str("]->s.s_gfdef)",VV[44]);
 	{object V74 = Cnil;
 	VMR9(V74)}
@@ -379,27 +375,25 @@ object V77;object V78;
 {	 VMB10 VMS10 VMV10
 TTL:;
 	princ_str("\n	make_cclosure_new(LC",VV[44]);
-	(void)((*(LnkLI70))((V77)));
+	(void)((*(LnkLI69))((V77)));
 	princ_str(",Cnil,",VV[44]);
-	(void)((VFUN_NARGS=1,(*(LnkLI71))((V78))));
+	(void)((VFUN_NARGS=1,(*(LnkLI70))((V78))));
 	princ_str(",Cdata)",VV[44]);
 	{object V79 = Cnil;
 	VMR10(V79)}
 }
-static object  LnkTLI71(va_alist)va_dcl{va_list ap;va_start(ap);return(object )call_vproc(VV[71],&LnkLI71,ap);} /* WT-CLINK */
-static object  LnkTLI70(va_alist)va_dcl{va_list ap;va_start(ap);return(object )call_proc(VV[70],&LnkLI70,1,ap);} /* WT1 */
-static object  LnkTLI69(va_alist)va_dcl{va_list ap;va_start(ap);return(object )call_proc(VV[69],&LnkLI69,2,ap);} /* ADD-ADDRESS */
-static object  LnkTLI68(va_alist)va_dcl{va_list ap;va_start(ap);return(object )call_vproc(VV[68],&LnkLI68,ap);} /* ADD-INIT */
-static object  LnkTLI67(va_alist)va_dcl{va_list ap;va_start(ap);return(object )call_proc(VV[67],&LnkLI67,1,ap);} /* PUSH-DATA-INCF */
-static object  LnkTLI66(va_alist)va_dcl{va_list ap;va_start(ap);return(object )call_vproc(VV[66],&LnkLI66,ap);} /* MAKE-FUN */
-static object  LnkTLI65(va_alist)va_dcl{va_list ap;va_start(ap);return(object )call_proc(VV[65],&LnkLI65,1,ap);} /* ADD-SYMBOL */
-static object  LnkTLI64(va_alist)va_dcl{va_list ap;va_start(ap);return(object )call_vproc(VV[64],&LnkLI64,ap);} /* UNWIND-EXIT */
-static object  LnkTLI63(va_alist)va_dcl{va_list ap;va_start(ap);return(object )call_vproc(VV[63],&LnkLI63,ap);} /* C1LAMBDA-EXPR */
-static LnkT62(){ call_or_link(VV[62],&Lnk62);} /* NULL */
+static object  LnkTLI70(va_alist)va_dcl{va_list ap;va_start(ap);return(object )call_vproc(VV[70],&LnkLI70,ap);} /* WT-CLINK */
+static object  LnkTLI69(va_alist)va_dcl{va_list ap;va_start(ap);return(object )call_proc(VV[69],&LnkLI69,1,ap);} /* WT1 */
+static object  LnkTLI68(va_alist)va_dcl{va_list ap;va_start(ap);return(object )call_proc(VV[68],&LnkLI68,2,ap);} /* ADD-ADDRESS */
+static object  LnkTLI67(va_alist)va_dcl{va_list ap;va_start(ap);return(object )call_vproc(VV[67],&LnkLI67,ap);} /* ADD-INIT */
+static object  LnkTLI66(va_alist)va_dcl{va_list ap;va_start(ap);return(object )call_proc(VV[66],&LnkLI66,1,ap);} /* PUSH-DATA-INCF */
+static object  LnkTLI65(va_alist)va_dcl{va_list ap;va_start(ap);return(object )call_vproc(VV[65],&LnkLI65,ap);} /* MAKE-FUN */
+static object  LnkTLI64(va_alist)va_dcl{va_list ap;va_start(ap);return(object )call_proc(VV[64],&LnkLI64,1,ap);} /* ADD-SYMBOL */
+static object  LnkTLI63(va_alist)va_dcl{va_list ap;va_start(ap);return(object )call_vproc(VV[63],&LnkLI63,ap);} /* UNWIND-EXIT */
+static object  LnkTLI62(va_alist)va_dcl{va_list ap;va_start(ap);return(object )call_vproc(VV[62],&LnkLI62,ap);} /* C1LAMBDA-EXPR */
 static object  LnkTLI61(va_alist)va_dcl{va_list ap;va_start(ap);return(object )call_vproc(VV[61],&LnkLI61,ap);} /* MAKE-INFO */
 static object  LnkTLI60(va_alist)va_dcl{va_list ap;va_start(ap);return(object )call_proc(VV[60],&LnkLI60,1,ap);} /* C1LOCAL-CLOSURE */
 static LnkT59(){ call_or_link(VV[59],&Lnk59);} /* C2EXPR */
-static LnkT49(){ call_or_link(VV[49],&Lnk49);} /* EVAL */
 static object  LnkTLI58(va_alist)va_dcl{va_list ap;va_start(ap);return(object )call_vproc(VV[58],&LnkLI58,ap);} /* CMPWARN */
 static object  LnkTLI57(va_alist)va_dcl{va_list ap;va_start(ap);return(object )call_proc(VV[57],&LnkLI57,1,ap);} /* TYPE-FILTER */
 static object  LnkTLI56(va_alist)va_dcl{va_list ap;va_start(ap);return(object )call_proc(VV[56],&LnkLI56,2,ap);} /* TYPE-AND */
