@@ -1,5 +1,5 @@
 
-#include <cmpinclude.h>
+#include "cmpinclude.h"
 #include "describe.h"
 init_describe(){do_init(VV);}
 /*	local entry for function INSPECT-READ-LINE	*/
@@ -2276,10 +2276,9 @@ T960:;
 T961:;
 	{object V160;
 	object V161;
-	{ save_avma;
-	V162 = stoi(V159);
-	V163 = stoi(V158);
-	V160= make_integer(addii(V162,V163));restore_avma;}
+	V162 = make_fixnum(V159);
+	V163 = make_fixnum(V158);
+	V160= number_plus(V162,V163);
 	V161= small_fixnum(0);
 T965:;
 	if(!(number_compare((V161),(V160))>=0)){
@@ -2386,10 +2385,9 @@ T1019:;
 T1020:;
 	{object V176;
 	register object V177;
-	{ save_avma;
-	V178 = stoi(V175);
-	V179 = stoi(V174);
-	V176= make_integer(addii(V178,V179));restore_avma;}
+	V178 = make_fixnum(V175);
+	V179 = make_fixnum(V174);
+	V176= number_plus(V178,V179);
 	V177= small_fixnum(0);
 T1024:;
 	if(!(number_compare((V177),(V176))>=0)){
